pub struct ProxyTokenRes { /* private fields */ }Expand description
GET /api/auth/proxy-token
Generate a proxy token for federation (allows this user to authenticate on behalf of the server)
If idTag query parameter is provided and different from the current server, this will
perform a federated token exchange with the target server.